import * as XLSX from 'xlsx';
var decodeValue = function (value) {
    if (typeof value === 'string') {
        try {
            var textarea = document.createElement('textarea');
            textarea.innerHTML = value;
            return textarea.value;
        }
        catch (_a) {
            return value;
        }
    }
    return value;
};
var reorderDataWithColumns = function (data, columns) {
    var validColumns = columns.filter(function (c) { return !!(c === null || c === void 0 ? void 0 : c.field) && !!(c === null || c === void 0 ? void 0 : c.header_text); });
    return data.map(function (row) {
        var orderedRow = {};
        validColumns.forEach(function (col) {
            var value = row[col.field];
            orderedRow[col.header_text] = decodeValue(value !== null && value !== void 0 ? value : '');
        });
        return orderedRow;
    });
};
export var downloadExcel = function (_a) {
    var data = _a.data, setupData = _a.setupData;
    try {
        var workbook = XLSX.utils.book_new();
        var columns = (setupData === null || setupData === void 0 ? void 0 : setupData.excel_columns) || (setupData === null || setupData === void 0 ? void 0 : setupData.columns);
        if (columns && Array.isArray(columns)) {
            data = reorderDataWithColumns(data, columns);
        }
        var worksheet = XLSX.utils.json_to_sheet(data);
        XLSX.utils.book_append_sheet(workbook, worksheet, 'Sheet1');
        var now = new Date();
        var pad = function (n) { return n.toString().padStart(2, '0'); };
        var fileName = "Data.".concat(now.getFullYear()).concat(pad(now.getMonth() + 1)).concat(pad(now.getDate()), ".").concat(pad(now.getHours())).concat(pad(now.getMinutes())).concat(pad(now.getSeconds()), ".xlsx");
        var excelBuffer = XLSX.write(workbook, {
            bookType: 'xlsx',
            type: 'array',
        });
        var blob = new Blob([excelBuffer], {
            type: 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet',
        });
        return { blob: blob, fileName: fileName };
    }
    catch (error) {
        alert('Error generating Excel: ' + error);
    }
};
